SALLIE
######

Getting tv information.

.. image:: https://img.shields.io/pypi/v/sallie.svg
    :target: https://pypi.python.org/pypi/sallie

.. image:: https://img.shields.io/pypi/l/sallie.svg
    :target: https://pypi.python.org/pypi/sallie

.. image:: https://img.shields.io/pypi/dm/sallie.svg
    :target: https://pypi.python.org/pypi/sallie

